# Loading weekly data for wig20 and its components from stooq
################################################################################
rm(list=ls())

require(zoo)
require(xts)
require(lubridate)

# loading weakly wig20 data
# filename <- "https://stooq.pl/q/d/l/?s=wig20&i=w" for weekly data
filename <- "https://stooq.pl/q/d/l/?s=wig20&i=d"
x        <- read.csv(filename)
y        <- zoo(x$Zamkniecie, as.Date(x$Data))
data0    <- y

# adding the data for wig20 stocks
# for actual tickers look at: https://stooq.pl/t/?i=532
# ALR	ALIOR	
# CDR	CDPROJEKT	
# CPS	CYFRPLSAT	
# DNP	DINOPL
# JSW	JSW	
# KGH	KGHM	
# LPP	LPP	
# LTS	LOTOS	
# MBK	MBANK	
# OPL	ORANGEPL	
# PEO	PEKAO	
# PGE	PGE		
# PGN	PGNIG	
# PKN	PKNORLEN	
# PKO	PKOBP	
# PLY	PLAY	
# PZU	PZU	
# SPL	SANPL	
# TPE	TAURONPE

tickers = c("alr","cdr","cps","dnp","jsw","kgh","lpp","lts","mbk","opl","peo","pge","pgn","pkn","pko","ply","pzu","spl","tpe") 
for(tick in tickers){
  filename <- paste("https://stooq.pl/q/d/l/?s=",tick,"&i=d", sep = "")
  x        <- read.csv(filename)
  y        <- zoo(x$Zamkniecie, as.Date(x$Data))
  data0    <- merge(data0,y)
}            
names(data0) <- c("wig20",tickers)
data         <- window(data0,start = last(index(data0))-years(10))

# writting to csv
save(data,file="wig20.Rdata")
write.csv(as.data.frame(data),file="wig20.csv")

# Exchange rates
# see https://stooq.pl/t/?i=60
filename <- "https://stooq.pl/q/d/l/?s=eurpln&i=d"
x        <- read.csv(filename)
y        <- zoo(x$Zamkniecie, as.Date(x$Data))
data0    <- y

tickers = c("AUDPLN","JPYPLN","KRWPLN","NZDPLN","CHFPLN","CZKPLN","GBPPLN","HUFPLN","NOKPLN","RONPLN","SEKPLN","CADPLN","USDPLN")	

for(tick in tickers){
  filename <- paste("https://stooq.pl/q/d/l/?s=",tolower(tick),"&i=d", sep = "")
  x        <- read.csv(filename)
  y        <- zoo(x$Zamkniecie, as.Date(x$Data))
  data0    <- merge(data0,y)
}            
names(data0) <- c("EURPLN",tickers)

data         <- window(data0,start = last(index(data0))-years(10))

# writting to csv
save(data,file="PLN.Rdata")
write.csv(as.data.frame(data),file="PLN.csv")